==> love_rimi-0.0.0.1.tar.gz: love_rimi-0.0.0.1/README.md <==


# ProjectName

ProjectName and Description

<!-- PROJECT SHIELDS -->

[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]

<!-- PROJECT LOGO -->
<br />

<p align="center">
  <a href="https://github.com/SandmX/love_rimi">
    <img src="static/img/logo.png" alt="Logo" width="150" height="120">
  </a>

  <h3 align="center">"完美的"README模板</h3>
  <p align="center">
    一个"完美的"README模板去快速开始你的项目！
    <br />
    <a href="https://github.com/SandmX/love_rimi"><strong>探索本项目的文档 »</strong></a>
    <br />
    <br />
    <a href="https://github.com/SandmX/love_rimi/tree/main/test/example">查看Demo</a>
    ·
    <a href="https://github.com/SandmX/love_rimi/issues">报告Bug</a>
    ·
    <a href="https://github.com/SandmX/love_rimi/issues">提出新特性</a>
  </p>


</p>


 本篇README.md面向开发者

## 目录

- [上手指南](#上手指南)
  - [开发前的配置要求](#开发前的配置要求)
  - [安装步骤](#安装步骤)
- [文件目录说明](#文件目录说明)
- [开发的架构](#开发的架构)
- [部署](#部署)
- [使用到的框架](#使用到的框架)
- [贡献者](#贡献者)
  - [如何参与开源项目](#如何参与开源项目)
- [版本控制](#版本控制)
- [作者](#作者)
- [鸣谢](#鸣谢)

### 上手指南

请将所有链接中的“sandmx/love_rimi”改为“your_github_name/your_repository”



###### 开发前的配置要求

1. xxxxx x.x.x
2. xxxxx x.x.x

###### **安装步骤**

1. Get a free API Key at [https://example.com](https://example.com)
2. Clone the repo

```sh
git clone https://github.com/sandmx/love_rimi.git
```

### 文件目录说明


```
filetree 
├── README.md     
├── LICENSE       许可文件
├── /static/      静态文件夹 存放资源
├── /love_rimi/   love_rimi 包
│  ├── /this_un/  this_un 包
│  │  ├── /lang/  语言包存放目录
├── /test/
│  ├── /example/  示例目录
├── lang_maker.py 制作语言包脚本

```





### 开发的架构 

暂无

### 部署

暂无

### 使用到的框架

- [xxxxxxx](https://getbootstrap.com)
- [xxxxxxx](https://jquery.com)
- [xxxxxxx](https://laravel.com)

### 贡献者

[Sandmeyer](https://github.com/sandmx)

请阅读**CONTRIBUTING.md** 查阅为该项目做出贡献的开发者。

#### 如何参与开源项目

贡献使开源社区成为一个学习、激励和创造的绝佳场所。你所作的任何贡献都是**非常感谢**的。


1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



### 版本控制

该项目使用Git进行版本管理。您可以在repository参看当前可用版本。

### 作者

sandmx.work@gmail.com

知乎:xxxx  &ensp; qq:xxxxxx    

 *您也可以在贡献者名单中参看所有参与该项目的开发者。*

### 版权说明

该项目签署了GNU v3.0 授权许可，详情请参阅 [LICENSE](https://github.com/SandmX/love_rimi/blob/main/LICENSE)

### 鸣谢


- [GitHub Emoji Cheat Sheet](https://www.webpagefx.com/tools/emoji-cheat-sheet)
- [Img Shields](https://shields.io)
- [Choose an Open Source License](https://choosealicense.com)
- [GitHub Pages](https://pages.github.com)
- [Animate.css](https://daneden.github.io/animate.css)
- [xxxxxxxxxxxxxx](https://connoratherton.com/loaders)

<!-- links -->
[your-project-path]:SandmX/love_rimi/
[contributors-shield]: https://img.shields.io/github/contributors/SandmX/love_rimi.svg?style=flat-square
[contributors-url]: https://github.com/sandmx/love_rimi/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/sandmx/love_rimi.svg?style=flat-square
[forks-url]: https://github.com/sandmx/love_rimi/network/members
[stars-shield]: https://img.shields.io/github/stars/sandmx/love_rimi.svg?style=flat-square
[stars-url]: https://github.com/sandmx/love_rimi/stargazers
[issues-shield]: https://img.shields.io/github/issues/sandmx/love_rimi.svg?style=flat-square
[issues-url]: https://img.shields.io/github/issues/sandmx/love_rimi.svg
[license-shield]: https://img.shields.io/github/license/sandmx/love_rimi.svg?style=flat-square
[license-url]: https://github.com/SandmX/love_rimi/blob/main/LICENSE
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/sandmx

==> love_rimi-0.0.1.2.tar.gz: love_rimi-0.0.1.2/README.md <==


# love_rimi

A package used to describe the love between Rimi and Sandmeyer

<!-- PROJECT SHIELDS -->

[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]

<!-- PROJECT LOGO -->
<br />

<p align="center">
  <a href="https://github.com/SandmX/love_rimi">
    <img src="static/img/logo.png" alt="Logo" width="150" height="120">
  </a>
  <h3 align="center">love_rimi</h3>
  <p align="center">
    A package used to describe the love between Rimi and Sandmeyer
    <br />
    <a href="https://github.com/SandmX/love_rimi"><strong>探索本项目的文档 »</strong></a>
    <br />
    <br />
    <a href="https://github.com/SandmX/love_rimi/tree/main/test/example">查看Demo</a>
    ·
    <a href="https://github.com/SandmX/love_rimi/issues">报告Bug</a>
    ·
    <a href="https://github.com/SandmX/love_rimi/issues">提出新特性</a>
  </p>



</p>


 本篇README.md面向开发者

## 目录

- [上手指南](#上手指南)
  - [开发前的配置要求](#开发前的配置要求)
  - [安装步骤](#安装步骤)
- [文件目录说明](#文件目录说明)
- [开发的架构](#开发的架构)
- [部署](#部署)
- [使用到的框架](#使用到的框架)
- [贡献者](#贡献者)
  - [如何参与开源项目](#如何参与开源项目)
- [版本控制](#版本控制)
- [作者](#作者)
- [鸣谢](#鸣谢)

### 上手指南

请将所有链接中的“sandmx/love_rimi”改为“your_github_name/your_repository”



###### 开发前的配置要求

1. xxxxx x.x.x
2. xxxxx x.x.x

###### **安装步骤**

1. Get a free API Key at [https://example.com](https://example.com)
2. Clone the repo

```sh
git clone https://github.com/sandmx/love_rimi.git
```

### 文件目录说明


```
filetree 
├── README.md     
├── LICENSE       许可文件
├── /static/      静态文件夹 存放资源
├── /love_rimi/   love_rimi 包
│  ├── /this_un/  this_un 包
│  │  ├── /lang/  语言包存放目录
├── /test/
│  ├── /example/  示例目录
├── lang_maker.py 制作语言包脚本

```





### 开发的架构 

暂无

### 部署

暂无

### 使用到的框架

- [xxxxxxx](https://getbootstrap.com)
- [xxxxxxx](https://jquery.com)
- [xxxxxxx](https://laravel.com)

### 贡献者

[Sandmeyer](https://github.com/sandmx)

请阅读**CONTRIBUTING.md** 查阅为该项目做出贡献的开发者。

#### 如何参与开源项目

贡献使开源社区成为一个学习、激励和创造的绝佳场所。你所作的任何贡献都是**非常感谢**的。


1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



### 版本控制

该项目使用Git进行版本管理。您可以在repository参看当前可用版本。

### 作者

sandmx.work@gmail.com

知乎:xxxx  &ensp; qq:xxxxxx    

 *您也可以在贡献者名单中参看所有参与该项目的开发者。*

### 版权说明

该项目签署了GNU v3.0 授权许可，详情请参阅 [LICENSE](https://github.com/SandmX/love_rimi/blob/main/LICENSE)

### 鸣谢


- [GitHub Emoji Cheat Sheet](https://www.webpagefx.com/tools/emoji-cheat-sheet)
- [Img Shields](https://shields.io)
- [Choose an Open Source License](https://choosealicense.com)
- [GitHub Pages](https://pages.github.com)
- [Animate.css](https://daneden.github.io/animate.css)
- [xxxxxxxxxxxxxx](https://connoratherton.com/loaders)

<!-- links -->
[your-project-path]:SandmX/love_rimi/
[contributors-shield]: https://img.shields.io/github/contributors/SandmX/love_rimi.svg?style=flat-square
[contributors-url]: https://github.com/sandmx/love_rimi/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/sandmx/love_rimi.svg?style=flat-square
[forks-url]: https://github.com/sandmx/love_rimi/network/members
[stars-shield]: https://img.shields.io/github/stars/sandmx/love_rimi.svg?style=flat-square
[stars-url]: https://github.com/sandmx/love_rimi/stargazers
[issues-shield]: https://img.shields.io/github/issues/sandmx/love_rimi.svg?style=flat-square
[issues-url]: https://img.shields.io/github/issues/sandmx/love_rimi.svg
[license-shield]: https://img.shields.io/github/license/sandmx/love_rimi.svg?style=flat-square
[license-url]: https://github.com/SandmX/love_rimi/blob/main/LICENSE
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/sandmx
